Module diff_viewer

Module diff_viewer 

Diff Viewer Component

Rich diff display with syntax highlighting and line numbers.

Structs

BundleSummary
Summary of a node bundle displayed as a header
DiffHunk
A single diff hunk
DiffLine
A diff line with its type
DiffViewer
Enhanced diff viewer with syntax highlighting

Enums

DiffLineType
Type of diff line
DiffViewMode
Display mode for diffs