Diff Viewer Component
Rich diff display with syntax highlighting and line numbers.
Structs
- Bundle
Summary - Summary of a node bundle displayed as a header
- Diff
Hunk - A single diff hunk
- Diff
Line - A diff line with its type
- Diff
Viewer - Enhanced diff viewer with syntax highlighting
Enums
- Diff
Line Type - Type of diff line
- Diff
View Mode - Display mode for diffs